# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	GNU Readline XS library wrapper
Name:		perl-Term-ReadLine-Gnu
Version:	1.22
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Term-ReadLine-Gnu/
Source0:	http://search.cpan.org/CPAN/authors/id/H/HA/HAYASHI/Term-ReadLine-Gnu-%{version}.tar.gz
Patch0:		Term-ReadLine-Gnu-1.22-malloc.patch
Patch2:		Term-ReadLine-Gnu-1.22-local.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	expect, readline-devel, ncurses-devel
BuildRequires:	perl(AutoLoader)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(ExtUtils::testlib)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(strict)
BuildRequires:	perl(Term::ReadLine)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs, and filter out docfile dependencies (rpm 4.9 onwards)
%global __provides_exclude ^Gnu\\.so
%global __requires_exclude_from %{_docdir}/%{name}-%{version}/eg

%description
Term::ReadLine::Gnu (TRG) is an implementation of the interface to the GNU
Readline Library. This module gives you input line editing facility, input
history management facility, word completion facility, etc. It uses the real
GNU Readline Library and has the interface with the almost all variables and
functions that are documented in the GNU Readline/History Library. So you can
program your custom editing function, your custom completion function, and so
on with Perl. TRG may be useful for a C programmer to prototype a program that
uses the GNU Readline Library.

%prep
%setup -q -n Term-ReadLine-Gnu-%{version}

# Fix for CPAN RT#37194 (CPAN RT#56500) in 1.20 breaks F-9's 5.10.0 perl,
# so revert the fix there
%if "%{?fedora}" == "9"
%patch0
%endif

# We don't have perl in /usr/local/bin
%patch2

# Filter docfile dependencies (prior to rpm 4.9)
%global docmodules (Cwd|File::Listing|Getopt::Std|integer|Net::Domain|Net::FTP|POSIX|Term::ReadLine|Tk)
%global reqfilt /bin/sh -c "%{__perl_requires} | grep -Ev '^perl\\(%{docmodules}\\)'"
%define __perl_requires %{reqfilt}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
%{_fixperms} %{buildroot}

%check
# Expect is used so that we get a PTY, as if we were
# in a real terminal, where readline works
LANG=C expect -c '
	spawn make test
	expect eof
	exit [lindex [wait] 3]
'

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes eg README
%{_bindir}/perlsh
%{perl_vendorarch}/Term/
%{perl_vendorarch}/auto/Term/
%{_mandir}/man1/perlsh.1*
%{_mandir}/man3/Term::ReadLine::Gnu.3pm*

%changelog
* Thu Mar  6 2014 Paul Howarth <paul@city-fan.org> 1.22-1
- Update to 1.22
  - Make Kwalitee-friendly:
    - Add MakeMaker options for META.yml
    - Add Changelog
    - Fix POD errors
    - Make .pm versions consistent
    - Use "use warnings"
  - Makefile.PL dies on the CPAN Test for OpenBSD temporarily (hopefully)
- Package perlsh script and its manpage
- Update patches as needed

* Sat Mar  1 2014 Paul Howarth <paul@city-fan.org> 1.21-1
- Update to 1.21
  - Readline-6.1 support
    - New function rl_free_keymap
    - New variable rl_filename_rewrite_hook
  - Readline-6.3 support
    - New function rl_clear_history
    - New variables rl_signal_event_hook, rl_input_available_hook,
      rl_executing_key, rl_executing_keyseq, rl_key_sequence_length,
      rl_change_environment, rl_filename_stat_hook
  - Make the following variables read-only: rl_executing_macro, history_length,
    rl_readline_state, rl_explicit_arg, rl_numeric_arg, rl_editing_mode
  - Improve backward compatiblity variable and function definitions
  - Fix Term::ReadLine::Gnu::XS::_trp_completion_function not to perform a
    case-sensitive filter
  - Fix Gnu.xs:rl_initialize to be compiled with Perl 5.8.5 or before
  - Update Pod documents
  - t/readline.t, t/history.t: add variable access tests
  - t/readline.t: consider .svn directory on filename completion test and to
    set the standard tty setting before re_initialize() being called
  - eg/perlsh makes use of the deferred signal (safe signal) feature
  - Makefile.PL checks whether the xmalloc exported by readline is indeed
    called 'xmalloc' or whether it has been renamed to '_rl_malloc'
  - Makefile.PL: add -DTRL_READLINE_VERSION to show GNU Readline Library
    version in CPAN Tester Reports
  - t/00checkver.t: let messages go to stdout
  - README: add project home page URL and remove out-of-date descriptions
  - INSTALL: add a section "Install on Mac OS X"
- Update patches as needed

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> 1.20-5
- BR: perl(AutoLoader), perl(Carp), perl(Exporter), perl(ExtUtils::testlib),
  perl(Getopt::Long) and perl(Term::ReadLine)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop RPATH removal kludge
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> 1.20-4
- Rebuild for perl 5.14.1 in Rawhide
- Tweak provides/requires filters for rpm 4.9 compatibility
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> 1.20-3
- Rebuild for perl 5.12.1 in Rawhide

* Sun May 30 2010 Paul Howarth <paul@city-fan.org> 1.20-2
- Fix dist tag for RHEL-6 Beta

* Mon May  3 2010 Paul Howarth <paul@city-fan.org> 1.20-1
- Update to 1.20
  - Copy environment to avoid segfaults on some systems e.g. FreeBSD
  - Skip the test of rl_readline_version for GNU Readline Library 6.1
  - readline-6.1 support: (func rl_free_keymap, var rl_filename_rewrite_hook)
- Revert environment segfault fix with perl < 5.10.1 and use our patch instead

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> 1.19-2
- Make requires/provides filters simpler and more generic
- Kill bogus RPATHs for distros prior to FC-2
- Dist tag for Rawhide no longer needs special-casing

* Mon Mar 23 2009 Paul Howarth <paul@city-fan.org> 1.19-1
- Update to 1.19 (ensure the outstream fd inside the readline library is in
  sync - http://bugs.debian.org/236018; various test fixes)
- Drop visible bell test patch, no longer needed

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> 1.18-1
- Update to 1.18
- * better error checking of Makefile.PL
- * readline-6.0 support
- Filter out unwanted provides for perl shared objects
- Change bogus dependency filtering mechanism to tie in with provides filter
- Update to SLES-compatible dist tag macros
- No longer need to fix up permissions in %%prep

* Wed Jul  2 2008 Paul Howarth <paul@city-fan.org> 1.17a-2
- Add Lubomir Rintel's workaround from Fedora for perl 5.10.0 build issues
  (#453287, http://rt.perl.org/rt3/Ticket/Display.html?id=56500)
  Should not be needed when Bug #453646 is fixed
- Run test suite in an "expect" wrapper (add buildreq expect, can now
  include t/readline.t again) so we get a pseudo-terminal
- Add Lubomir Rintel's patch to disable visible bell test, which fails on
  perl 5.10.0
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Don't need buildreq bc (where did that come from?)

* Fri Feb  8 2008 Paul Howarth <paul@city-fan.org> 1.17a-1
- Update to 1.17a
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Don't run t/readline.t test since it's interactive
- Update patch to fix references to /usr/local/bin/perl

* Wed Jun  6 2007 Paul Howarth <paul@city-fan.org> 1.16-3
- Fix dist tag for Fedora 7 onwards
- Add buildreq perl(ExtUtils::MakeMaker)
- Fix argument order for find with -depth

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> 1.16-2
- Fix distribution tags for development releases
- Define %%{__id_u} in a more portable way
- Further simplify bogus dependency filter
- Don't use macros in build-time command paths, hardcode them instead
- Carry on if tests fail (can't read /dev/tty in mock on FC5 onwards)
- Add buildreq ncurses-devel

* Tue Apr  4 2006 Paul Howarth <paul@city-fan.org> 1.16-1
- Update to 1.16
- Remove buildroot unconditionally in %%clean and %%install
- Own directories properly
- Simplify distribution-detection
- Remove %%__perl_vendorlib macro, not used
- Remove %%__perl_version macro, used only once
- Remove %%__perl_package macro, used only twice
- Use search.cpan.org URLs
- Simplify compiler optimization flag setting
- Simplify filtering of bogus dependencies

* Fri Jun 24 2005 Paul Howarth <paul@city-fan.org> 1.15-3
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Include README and examples

* Thu Dec  2 2004 Paul Howarth <paul@city-fan.org> 1.15-2
- Run "make test" with LANG=C to avoid problems with readline 4.3

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> 1.15-1
- Update to 1.15
- Tidy up spec file

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> 1.14-3
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM.
- Changed distribution-identifying macros for greater portability.

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> 1.14-2
- Unified spec file for Red Hat and Fedora Core

* Fri Dec 12 2003 Paul Howarth <paul@city-fan.org> 1.14-1.fc1
- More macros
- Expanded description
- Add Fedora Core version to RPM release ID

* Wed Nov 26 2003 Paul Howarth <paul@city-fan.org> 1.14-1
- Update to 1.14
- Patch modules to remove hardcoded references to /usr/local/bin/perl

* Mon Nov 24 2003 Paul Howarth <paul@city-fan.org>
- Tweak for Fedora

* Sat Oct 26 2002 R P Herrold <herrold@owlriver.com.com>
- Fork and re-config from Chip Turner's <cturner@redhat.com> 
  .spec for perl-Date-Calc.spec
